#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Aug 26 16:04:07 2017

@author: misakawa
"""

class indicates:
    content = dict()
    def log(name, explanation, url):
        indicates.content[name] = dict(explanation = explanation, doc_url = url)
indicates.log('Pulse',  expl, 'http://materializecss.com/pulse.html') where:
    expl = ["btn btn-floating pulse",
            "btn btn-floating btn-large pulse", 
            "btn btn-floating btn-large cyan pulse"]

indicates.log('Shadow', expl, 'http://materializecss.com/shadow.html') where:
    expl = ['z-depth-1','z-depth-<int>']
    
indicates.log("Transitions", expl, 'http://materializecss.com/css-transitions.html') where:
    expl = ['scale-transition', 'scale-out', 'scale-in', 'flow-text']


    
    
    
    


# -*- coding: utf-8 -*-

def align(self):
    if self -> not hasattr(_, 'align_setted'):
        self.align_setted = True
    else:
        raise BaseException("Alignment has been set twice!!!")
    def _f(mode):
        mode = mode.replace(" ","")
        if mode not in ("left","right", "center"):
            raise ValueError('''Found align-mode not in  ("left","right", "center")!!!''')
        self.cons_attr('class')(mode+'-align')
        return self
    return _f

def left_align(self):
    return align(self)("left")

def right_align(self):
    return align(self)("right")

def center_align(self):
    return align(self)("center")

    


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Aug 31 21:29:47 2017

@author: misakawa
"""

from ..abst import abstract_object,indent_setter, attrset_sugar, Seq
from ..CSS.Grid import col

class input_field(col): 
    """
    See http://materializecss.com/forms.html
    user help : >> help (input_field.init)
        Guide:
            input_field(field_name = 'Username', type = 'text', icon = icon('mode_edit'), id = 'for-username')
    
        Take care for `submit`:
            submit = \
            input_field(field_name = "TiJiao/Submit",
                        type = 'submit',
                        icon = icon('publish'),
                        )
    """
    def init(self, grid : "CSS.Grid.grid" ,  **attributes):
        sugar = attrset_sugar(self.conf, attributes)
        sugar('icon', None)
        sugar('id', 'Some Id')
        sugar('type', 'text')
        sugar('field_name', 'Some Field')
        if self.conf['type'].lower() == 'submit':
            if 'class' not in attributes:
                attributes['class'] =  "waves-effect waves-light btn"
            else:
                attributes['class'] += "waves-effect waves-light btn"
            body =\
"""
{{indent}}<input {{attributes_dict}} id="{{id}}" name = "{{id}}" type = "{{type}}">
"""
        else:
            sugar('class', 'validate')
            body =\
"""
{{indent}}<div {{attributes_dict}}>
{{indent+Indent_unit}}<input id="{{id}}" name = "{{id}}" class="{{class}}" type = "{{type}}">
{{indent+Indent_unit}}<label for="{{id}}">{{field_name}}</label>
{{indent}}</div>
""" 
        self.conf.update(dict(indent = " ", attributes_dict = attributes))
        self.append_class(grid.gen())
        self.body = body
        self.cons_class("input-field")
        
        
class form(indent_setter, abstract_object):
    """
    See http://materializecss.com/forms.html
    user help : >> help (form.init)
        Guide:
            a_form = form(
                        Seq(
                        input_field(grid(s=12), field_name = 'Username', type = 'text',     icon = icon('mode_edit'), id = 'for-username'),
                        input_field(grid(s=12), field_name = 'Password', type = 'password', icon = icon('brightness_auto'),   id = 'for-password'),
                        input_field(grid(s=12), field_name = 'School',   type = 'text',     icon = icon('brightness_3'),   id = 'for-school'),
                        input_field(grid(s=12), field_name = 'submit',   type = 'submit',   icon = icon('publish'),   id = 'for-submit')->> right_align,
                        ),
                        action = 'script',
                        method = 'POST')
    """
    
    def init(self, content :(Seq,[input_field]), **attributes):
        body = \
"""
{{indent}}<form {{attributes_dict}}>
{{indent+Indent_unit}}{{content}}
{{indent}}</form>
"""
        self.conf.update(dict(content = content, indent = " ", attributes_dict = attributes))
        self.body = body



        


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Aug 31 20:18:27 2017

@author: misakawa
"""


from ..abst import abstract_object,indent_setter, default_attr, attrset_sugar
from .Icons import mode_edit
class FAB(indent_setter, abstract_object):
    """
    See http://materializecss.com/buttons.html
    user help : >> help (FAB.init)
        Guide:
            from incantation.Module.Component.Icons import icon
            fab = FAB([dict(color = 'red',  icon = icon("insert_chart"),  href = ...),
                       dict(color = 'blue', icon = icon("publish"),       href = ...),
                       ...
                       ], loc = 'relative')
    """
    @default_attr(attr = 'class', value = 'fixed-action-btn')
    def init(self, content, **attributes):
        sugar = attrset_sugar(self.conf, attributes)
        sugar('color', 'red')
        sugar('icon', mode_edit)
        sugar('horizon',  False)
        sugar('loc', "fixed")
        if self.conf['horizon']:
            attributes['class']+=' horizontal'
        body =\
"""
{{indent}}<div {{attributes_dict}} {% if loc != 'fixed' %}style="position: {{loc}};"{% else %} {% endif %}>
{{indent+Indent_unit}}<a class="btn-floating btn-large {{color}}">
{{indent+Indent_unit*2}}<i class="large material-icons">{{icon}}</i>
{{indent+Indent_unit}}</a>
{{indent+Indent_unit}}<ul>
{{indent+Indent_unit}}{% for subicon in content %}
{{indent+Indent_unit*2}}<li><a href="{{subicon.href}}" class="btn-floating {{subicon.color}}">{{subicon.icon}}</a></li>
{{indent+Indent_unit}}{% endfor %}
{{indent+Indent_unit}}</ul>
{{indent}}</div>
"""
        self.conf.update(dict(content = content, indent = '',  attributes_dict = attributes))
        self.body = body
        
class raised(indent_setter, abstract_object):
    """
    See http://materializecss.com/buttons.html
    user help : >> help (raised.init)
        Guide:
            button1 = raised(icon = icon('add_alarm'), name = "YHZ", href = 'https://www.baidu.com') 
    """
    @default_attr(attr = 'class', value = 'waves-effect waves-light btn')
    def init(self, **attributes):
        sugar = attrset_sugar(self.conf, attributes)
        sugar("name", "button")
        sugar("icon", None)
        self.body = \
"""
<a {{attributes_dict}}>{% if icon %}{{icon}}{% endif %}{{name}}</a>
"""
        self.conf.update(dict(indent = '',  attributes_dict = attributes))
        
        


# -*- coding: utf-8 -*-

from .. import foreach, groupby, andThen, compose, flow_map, flatten, fastmap
from .abst import abstract_object,indent_setter, default_attr
class blockquote(indent_setter, abstract_object):
    """
    See http://materializecss.com/typography.html
    user help : >> help (blockquote.init)
    ------------------------------
        Guide:
           blockquote("Tips here!")
    """
    def init(self, content, **attributes):
        body = \
"""
{{indent}}<blockquote {{attributes_dict}}>
{{indent+Indent_unit}}{{content}}.
{{indent}}</blockquote>
"""
        self.conf.update(dict(content = content, indent = '',  attributes_dict = attributes))
        self.body = body
        


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Aug 31 14:53:43 2017

@author: misakawa
"""

from ..abst import abstract_object,indent_setter, Seq, default_attr, attrset_sugar

def badge(name, href = '#!', new:{True,False,None} = None,  num = "", color = ''):
    if new is None:
        return dict(href=href, style=f"{name}")
    class_ = 'new badge' if new else 'badge'
    if color: class_ += color
    return dict(href = href, style = f'{name}<span class="{class_}">{num}</span>')
        

class collections(indent_setter, abstract_object):
    """
    See http://materializecss.com/badges.html
    user help : >> help (collections.init)
        Guide:
            >> cs = collections([badge(new = False,href = '#!', num = 1, name = 'Alan'),
                                 badge(new = True, href = '#!', num = 4, name = 'Alan'),
                                 badge(href = '#!', name = 'Alan'),
                                 badge(new = False,href = '#!', num = 14,name = 'Alan')
                                ],
                                )
            >> cs
              <div class="collection">
                  <a href="#!" class="collection-item"><span class="badge">1</span>Alan</a>
                  <a href="#!" class="collection-item"><span class="new badge">4</span>Alan</a>
                  <a href="#!" class="collection-item">Alan</a>
                  <a href="#!" class="collection-item"><span class="badge">14</span>Alan</a>
              </div>
    """
    @default_attr(attr = 'class', value = "collection")
    def init(self, content : (list,[badge]), **attributes):
        body   = \
"""
{{indent}}<div {{attributes_dict}}>
{{indent+Indent_unit}}{% for badge in content%}
{{indent+Indent_unit*2}}<a href="{{badge.href}}" class="collection-item">{{badge.style}}</a>
{{indent+Indent_unit}}{% endfor %}
{{indent}}</div>
"""      
        self.conf.update(dict(content = content, indent = '',  attributes_dict = attributes))
        self.body = body
        
    
class dropdown(indent_setter, abstract_object):
    """
    See http://materializecss.com/badges.html
    user help : >> help (dropdown.init)
         Guide:
             dd = dropdown([badge(new = False,href = '#!', num = 1, name = 'Alan'),
                            badge(new = True, href = '#!', num = 4, name = 'Alan'),
                            badge(href = '#!', name = 'Alan'),
                            badge(new = False,href = '#!', num = 14,name = 'Alan')
                            ],
                            name = 'a dropdown list', id = 'someid'
                            )
             
    """
    def init(self, content:(list,[badge]), **attributes:dict(material_icons = 'arrow_drop_down')):
        body = \
"""
{{indent}}<ul id="{{id}}" class="dropdown-content">
{{indent+Indent_unit}}{% for badge in content%}
{{indent+Indent_unit*2}}<li><a href="{{badge.href}}">{{badge.style}}</a></li>
{{indent+Indent_unit}}{% endfor %}
{{indent}}</ul>
{{indent}}<a {{attributes_dict}} data-activates="{{id}}">{{name}}<i class="material-icons right">{{material_icons}}</i></a>
           
"""
        sugar = attrset_sugar(self.conf, attributes)
        sugar('name', 'Dropdown[name = ???]')
        sugar('id', 'ID[unknown]')
        sugar('material_icons', 'arrow_drop_down')
        
        @default_attr(attr = 'class', value = 'btn dropdown-button')
        @default_attr(attr = 'href' , value = '#!')
        def  _init_(content:(list,[dict]), **attributes):
            self.conf.update(dict(content = content, indent = '',  attributes_dict = attributes))
            self.body = body
        _init_(content, **attributes)
        

class collapsible(indent_setter, abstract_object):
    """
    See http://materializecss.com/badges.html
    user help : >> help (collapsible.init)
        Guide:
            collap = collapsible([(icon('filter_drama'),badge(href = '#!', name = "First") , "<p>Lorem ipsum dolor sit amet.</p>"),
                                  (icon('place'),       badge(href = '#!', name = "Second"), "place")
                                 ])
    """
    @default_attr(attr = 'class', value = "collapsible")
    @default_attr(attr = 'data-collapsible', value = 'accordion')
    def init(self, content, **attributes):
        body = \
"""
{{indent}}<ul {{attributes_dict}}>
{{indent+Indent_unit}}{% for item in content %}
{{indent+Indent_unit}}<li>
{{indent+Indent_unit}}<div class="collapsible-header">
{{indent+Indent_unit}}{{item[0]}}
{{indent+Indent_unit}}<a href="{{item[1].href}}">{{item[1].style}}</a>
{{indent+Indent_unit}}</div>
{{indent+Indent_unit}}<div class="collapsible-body">
{{indent+Indent_unit}}{{item[2]}}
{{indent+Indent_unit}}</div>
{{indent+Indent_unit}}</li>
{{indent+Indent_unit}}{% endfor %}
{{indent}}</ul>
"""
        self.conf.update(dict(content = content, indent = '',  attributes_dict = attributes))
        self.body = body
        
    
    
        


from .Module.abst import abstract_object, gen_helper
from jinja2 import Template
Body=\
"""
  <!DOCTYPE html>
  <html>
    <head>
      <!--Import Google Icon Font-->
      <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
      <!--Import materialize.css-->
      <link type="text/css" rel="stylesheet" href="static/materialize/css/materialize.min.css"  media="screen,projection"/>

      <!--Let browser know website is optimized for mobile-->
      <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
      <meta charset="utf-8">
    </head>

    <body>
      <!--Import jQuery before materialize.js-->
      <script type="text/javascript" src="static/jquery-3.2.1.min.js"></script>
      <script type="text/javascript" src="static/materialize/js/materialize.min.js"></script>
      {{body}}
    </body>
  </html>
"""

class Page:
    """  user help : >> help (Page.init)   
            Guide:
                page = Page( content )
                page.write('./test.html')
                
    """
    def __init__(self, body = ""):
        self.body = gen_helper(body) 
    def __str__(self):
        return Template(Body).render(body  = self.body)
    def write(self, to = './test.html'):
        with open(to, 'w', encoding = 'utf-8') as f:
            Template(Body).render(body  =  self.body) ->> f.write
    def gen(self):
        return Template(Body).render(body  = self.body)
        

        





# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
import io

with io.open('./ReadMe.md', encoding='utf-8') as f:
    readme = f.read()

with io.open('LICENSE', encoding='utf-8') as f:
    print(f.read())
if input("Do you approve the license terms? [yes|no]") != 'yes':
    print("I'm Sorry that you cannot accept the license. Have a nice day :)")
else:
    import os
    cat = os.path.join
    setup(
        name = 'Incantation',
        version = '0.1',
        keywords='website, web-design',
        description = "Python Object Design about Website. Make Developing websites like saying incantations.",
        long_description=readme,
        license = 'MIT License',
        url = 'https://github.com/thautwarm/Incantation',
        author = 'Thautwarm',
        author_email = 'twshere@outlook.com',
        packages = find_packages(),
        include_package_data = True,
        platforms  = ['windows','linux'],
        classifiers=['Programming Language :: Python :: 3.6','Programming Language :: Python :: Implementation :: CPython'],
        install_requires=[
        'flowpython>=0.2.3',
        ]
    )

    os.system("python -m flowpython -m enable")


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Aug 31 17:20:58 2017

@author: misakawa
"""
ICON_URL = 'http://materializecss.com/icons.html'

def icon(name, loc = ''):
    return f'<i class="material-icons {loc}" >{name}</i>'

mode_edit      = icon('mode_edit')
add            = icon('add')
access_alarm   = icon('access_alarm')
account_box    = icon('account_box')
account_circle = icon('account_circle')
all_inclusive  = icon('all_inclusive')
android        = icon('android')
arrow_upward   = icon('arrow_upward')
arrow_downward = icon('arrow_downward')
attach_file    = icon('attach_file')
cloud          = icon('cloud')